<?php

namespace Drupal\whatsapp_business\Breadcrumb;

use Drupal\Core\Breadcrumb\Breadcrumb;
use Drupal\Core\Breadcrumb\BreadcrumbBuilderInterface;
use Drupal\Core\Link;
use Drupal\Core\Routing\RouteMatchInterface;

/**
 *
 */
class BreadcrumbBuilder implements BreadcrumbBuilderInterface {

  protected $currentRouteMatch;
  protected $urlGenerator;

  public function __construct(RouteMatchInterface $current_route_match, $url_generator) {
    $this->currentRouteMatch = $current_route_match;
    $this->urlGenerator = $url_generator;
  }

  /**
   *
   */
  public function applies(RouteMatchInterface $route_match) {
    // Apply this builder only to specific routes.
    $routes = ['whatsapp_business.settings', 'whatsapp_business.test_message'];
    return in_array($route_match->getRouteName(), $routes);
  }

  /**
   *
   */
  public function build(RouteMatchInterface $route_match) {
    $breadcrumb = new Breadcrumb();
    $breadcrumb->addCacheContexts(['route']);

    // Add "Configuration" breadcrumb link.
    $breadcrumb->addLink(Link::createFromRoute('Configuration', 'system.admin_config'));

    // Add "Services" breadcrumb link.
    $breadcrumb->addLink(Link::createFromRoute('Services', 'system.admin_config_services'));

    // Add "Whatsapp Business Settings" link for specific routes.
    if ($route_match->getRouteName() === 'whatsapp_business.test_message') {
      $breadcrumb->addLink(Link::createFromRoute('Whatsapp Business Settings', 'whatsapp_business.settings'));
    }

    // Add current page title.
    $breadcrumb->addLink(Link::createFromRoute($route_match->getRouteObject()->getDefault('_title'), $route_match->getRouteName()));

    return $breadcrumb;
  }

}
