<?php

/**
 * @file
 */

/**
 * Send OTP to the selected delivery method.
 */
public function sendOtpSubmit(array &$form, FormStateInterface $form_state) {
  $mobile_number = $form_state->getValue('mobile_number');
  // Assume it's a checkbox array.
  $otp_delivery_method = $form_state->getValue('otp_delivery_method');

  // Generate a numeric OTP.
  $generated_otp = mt_rand(100000, 999999);

  // Save OTP and mobile number in the database.
  Database::getConnection()->insert('join_dmk_log')->fields([
    'mobile_number' => $mobile_number,
    'otp' => $generated_otp,
    'created' => \Drupal::time()->getRequestTime(),
  ])->execute();

  $message_sent = FALSE;

  // Loop through selected delivery methods.
  foreach ($otp_delivery_method as $method) {
    if ($method === 'sms') {
      // SMS sending logic here (existing functionality).
      $message_sent = TRUE;
    }
    elseif ($method === 'whatsapp') {
      // Get WhatsAppService and send OTP.
      /** @var \Drupal\whatsapp_business\WhatsAppService $whatsapp_service */
      $whatsapp_service = \Drupal::service('whatsapp_business.service');
      if ($whatsapp_service->sendOtp('+91' . $mobile_number, $generated_otp)) {
        $message_sent = TRUE;
      }
      else {
        \Drupal::messenger()->addError($this->t('Failed to send OTP via WhatsApp.'));
      }
    }
  }

  if ($message_sent) {
    \Drupal::messenger()->addMessage($this->t('An OTP has been sent to the selected delivery methods.'));
  }
  else {
    \Drupal::messenger()->addError($this->t('Failed to send OTP. Please try again.'));
  }

  // Set form state for OTP fieldset display.
  $form_state->set('otp_sent', TRUE);
  $form_state->setRebuild(TRUE);
}
